%define major      7
%define libname    %mklibname %{name} %{major}
%define develname  %mklibname %{name} -d

%define url_ver %(echo %{version}|sed -e 's/\\./\\-/g')

Name:           openbabel
Version:        3.1.1
Release:        %mkrel 12
Summary:        Chemistry software file format converter
License:        GPLv2+
Group:          Sciences/Chemistry
URL:            https://openbabel.org/wiki/Main_Page
Source:         https://github.com/openbabel/openbabel/releases/download/openbabel-%{url_ver}/%{name}-%{version}-source.tar.bz2
Source1:        openbabelgui.desktop
# fix perl modules install path
Patch1:         %{name}-perl.patch
# fix plugin directory location (#680292, patch by lg)
Patch4:         openbabel-plugindir.patch
Patch5:         openbabel-pkgconfig-and-cmake-libdir.patch
Patch6:         openbabel-noswig-rubymethod.patch
Patch7:         openbabel-ruby19-vendorarch.patch
Patch9:         openbabel-2.4.1-ruby27.patch
Patch10:	0001-CMake-fix-time-check-typo-fixes-build-failure-w-GCC-.patch
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  imagemagick
BuildRequires:  swig
BuildRequires:  boost-devel
BuildRequires:  inchi-devel >= 1.0.4
BuildRequires:  perl-devel
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  wxgtk-devel
BuildRequires:  cmake(coordgen)
BuildRequires:  cmake(maeparser)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(RapidJSON)
BuildRequires:  pkgconfig(ruby)
BuildRequires:  pkgconfig(zlib)

%description
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

%package -n     %{libname}
Summary:        Shared libraries of %{name}
Group:          System/Libraries

%description -n %{libname}
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

This package contains shared libraries of %{name}.

%package -n     %{develname}
Summary:        Development files of %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}
Requires:       inchi-devel >= 1.0.4
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

This package includes the header files and other development
related files necessary for developing or compiling programs
using the %{name} library.

%package -n     perl-%{name}
Group:          Development/Perl
Summary:        Perl wrapper for the Open Babel library

%description -n perl-%{name}
Perl wrapper for the Open Babel library.

%package -n     python3-%{name}
Group:          Development/Python
Summary:        Python3 wrapper for the Open Babel library
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
Python 3 wrapper for the Open Babel library.

%package -n     ruby-%{name}
Summary:        Ruby wrapper for the Open Babel library
Group:          Development/Ruby
Requires:       %{name} = %{version}-%{release}

%description -n ruby-%{name}
Ruby wrapper for the Open Babel library.

%prep
%setup -q
%autopatch -p1
convert src/GUI/babel.xpm -transparent white babel.png

%build
%cmake \
   -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
   -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
   -DENABLE_TESTS:BOOL=OFF \
   -DBUILD_GUI:BOOL=ON \
   -DENABLE_VERSIONED_FORMATS=false \
   -DPYTHON_BINDINGS:BOOL=ON \
   -DPYTHON_EXECUTABLE=%{__python3} \
   -DPERL_BINDINGS:BOOL=ON \
   -DRUBY_BINDINGS:BOOL=ON \
   -DRUN_SWIG=true \
   -DOPENBABEL_USE_SYSTEM_INCHI=ON
%cmake_build

%install
touch scripts/CMakeLists.txt
%cmake_install

chmod 0755 %{buildroot}%{perl_vendorarch}/auto/Chemistry/OpenBabel/OpenBabel.so
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE1}
install -Dpm644 babel.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/babel.png

%files
%doc AUTHORS COPYING README.md THANKS
%doc doc/*.html doc/diox* doc/README*
%{_bindir}/*
%{_mandir}/man?/*
%{_datadir}/%{name}/
%{_datadir}/applications/*
%{_datadir}/icons/hicolor/*/*/*
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/*
%{_libdir}/cmake/openbabel3/
%{_libdir}/pkgconfig/%{name}-3.pc
%{_libdir}/lib%{name}.so

%files -n perl-%{name}
%{perl_vendorarch}/*

%files -n python3-%{name}
%{python3_sitearch}/%{name}/

%files -n ruby-%{name}
%{ruby_vendorarchdir}/openbabel.so


%changelog
* Fri Jul 15 2022 wally <wally> 3.1.1-12.mga9
+ Revision: 1868994
- rebuild for wxgtk 3.2.0

* Mon Jun 13 2022 wally <wally> 3.1.1-11.mga9
+ Revision: 1864222
- fix build with GCC 12
- rebuild for wxgtk 3.1.7

* Tue Jun 07 2022 umeabot <umeabot> 3.1.1-10.mga9
+ Revision: 1863341
- Rebuild for Perl 5.36

* Fri Apr 15 2022 wally <wally> 3.1.1-9.mga9
+ Revision: 1849971
- rebuild for wxgtk 3.1.6

* Mon Apr 04 2022 umeabot <umeabot> 3.1.1-8.mga9
+ Revision: 1842991
- Mageia 9 Mass Rebuild

* Fri Feb 25 2022 pterjan <pterjan> 3.1.1-7.mga9
+ Revision: 1784570
- Rebuild for Ruby 3.1

* Sat Jan 15 2022 wally <wally> 3.1.1-6.mga9
+ Revision: 1768499
- rebuild for wxgtk 3.1.5 with working wxSizer::SetSizeHints()

* Sat Jan 01 2022 wally <wally> 3.1.1-5.mga9
+ Revision: 1765838
- skip RPATH
- rebuild for wxgtk 3.1.5 to resolve 'Symbol X has different size in shared object, consider re-linking' error

* Mon May 24 2021 umeabot <umeabot> 3.1.1-4.mga9
+ Revision: 1727961
- Rebuild for perl 5.34

* Mon Apr 26 2021 daviddavid <daviddavid> 3.1.1-3.mga9
+ Revision: 1719866
- fix a typo in previous patch

* Mon Apr 26 2021 daviddavid <daviddavid> 3.1.1-2.mga9
+ Revision: 1719822
- fix pkgconfig and OpenBabel3_EXPORTS.cmake libdir

* Mon Apr 26 2021 daviddavid <daviddavid> 3.1.1-1.mga9
+ Revision: 1719801
- new version: 3.1.1
- now libmajor is 7

* Thu Mar 25 2021 daviddavid <daviddavid> 2.4.1-15.mga9
+ Revision: 1710172
- rebuild for python 3.9

* Fri Jan 01 2021 wally <wally> 2.4.1-14.mga8
+ Revision: 1667706
- rebuild for wxgtk pre 3.1.5 snapshot

* Sun Aug 16 2020 wally <wally> 2.4.1-13.mga8
+ Revision: 1614347
- rebuild for new wxgtk 3.1.4

* Sun Jun 21 2020 tv <tv> 2.4.1-12.mga8
+ Revision: 1598310
- rebuild for perl-5.32

* Tue Mar 03 2020 daviddavid <daviddavid> 2.4.1-11.mga8
+ Revision: 1553383
- add a minimum patch to support ruby 2.7
+ pterjan <pterjan>
- Rebuild for ruby 2.7

* Tue Feb 18 2020 umeabot <umeabot> 2.4.1-10.mga8
+ Revision: 1538041
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Tue Nov 12 2019 wally <wally> 2.4.1-9.mga8
+ Revision: 1459651
- switch to python3
- rebuild for wxgtk 3.1.3

* Tue Aug 27 2019 tmb <tmb> 2.4.1-8.mga8
+ Revision: 1433865
- rebuild for perl 5.30

* Mon Jul 08 2019 wally <wally> 2.4.1-7.mga8
+ Revision: 1419530
- rebuild for wxgtk 3.1.2 with 2.8 compatibility

* Sun Jul 07 2019 wally <wally> 2.4.1-6.mga8
+ Revision: 1419285
- rebuild with gtk3 enabled wxgtk 3.1.2

* Sun Sep 23 2018 umeabot <umeabot> 2.4.1-5.mga7
+ Revision: 1299977
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 pterjan <pterjan> 2.4.1-4.mga7
+ Revision: 1248931
- Rebuild for perl 5.28

* Sat Jan 27 2018 pterjan <pterjan> 2.4.1-3.mga7
+ Revision: 1197333
- Add upstream patch fixing build on arm

* Mon Jan 01 2018 pterjan <pterjan> 2.4.1-2.mga7
+ Revision: 1188463
- Rebuild for Ruby 2.5

* Wed Sep 13 2017 tv <tv> 2.4.1-1.mga7
+ Revision: 1153528
- new release
- fix build with new ruby
- adjust file list
+ pterjan <pterjan>
- Rebuild for new Ruby

* Sat Jul 22 2017 neoclust <neoclust> 2.3.2-20.mga7
+ Revision: 1126602
- Rebuild against new Perl 5.26

* Sat Jun 03 2017 akien <akien> 2.3.2-19.mga6
+ Revision: 1106105
- Rebuild for wxgtk 3.0.3.1

* Thu Jun 02 2016 daviddavid <daviddavid> 2.3.2-18.mga6
+ Revision: 1019818
- rebuild for wxgtk3.0 built with GTK2

* Tue Feb 16 2016 umeabot <umeabot> 2.3.2-17.mga6
+ Revision: 961821
- Mageia 6 Mass Rebuild

* Wed Nov 11 2015 daviddavid <daviddavid> 2.3.2-16.mga6
+ Revision: 902028
- rebuild for new ruby 2.2.3

* Wed Aug 26 2015 fwang <fwang> 2.3.2-15.mga6
+ Revision: 869549
- fix build with gcc5
- rebuild for gcc5

* Fri Aug 14 2015 ycantin <ycantin> 2.3.2-14.mga6
+ Revision: 864698
- rebuild for new wxgtk built with wxRE_ADVANCED

* Thu Jul 23 2015 akien <akien> 2.3.2-13.mga6
+ Revision: 856371
- Rebuild for wxgtk with gtk3

* Sun Jun 28 2015 tv <tv> 2.3.2-12.mga6
+ Revision: 846866
- rebuild with soname-ified perl

* Wed Jun 24 2015 sander85 <sander85> 2.3.2-11.mga6
+ Revision: 842497
- Rebuild for perl 5.22

* Sun Nov 16 2014 alexl <alexl> 2.3.2-10.mga5
+ Revision: 797514
- translated desktop file into Russian and Ukrainian

* Wed Oct 15 2014 umeabot <umeabot> 2.3.2-9.mga5
+ Revision: 747597
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.3.2-8.mga5
+ Revision: 727499
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.3.2-7.mga5
+ Revision: 683187
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 2.3.2-6.mga5
+ Revision: 630735
- Rebuild for perl 5.20
- Rebuild for new Python

* Wed Feb 05 2014 fwang <fwang> 2.3.2-4.mga5
+ Revision: 583572
- try build with wxwidgets 3.0

* Mon Oct 21 2013 umeabot <umeabot> 2.3.2-3.mga4
+ Revision: 538736
- Mageia 4 Mass Rebuild

* Sat Sep 21 2013 fwang <fwang> 2.3.2-2.mga4
+ Revision: 482943
- rebuild for ruby 2.0

* Sat Aug 17 2013 fwang <fwang> 2.3.2-1.mga4
+ Revision: 467105
- strip whitespace
- install python binding into correct dir
- update file list
- add fedora patch to fix cmake script
- new version 2.3.2

* Wed May 29 2013 fwang <fwang> 2.3.1-5.mga4
+ Revision: 430422
- rebuild for new perl

* Sun Jan 13 2013 umeabot <umeabot> 2.3.1-4.mga3
+ Revision: 361909
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Nov 05 2012 fwang <fwang> 2.3.1-3.mga3
+ Revision: 314329
- add fedora patch to have it built
- fix ruby inc path
- more inlclude dir fix
- specify correct includedir
+ jquelin <jquelin>
- perl 5.16 rebuild
+ gil <gil>
- edit cmake option remove java bindings
- rebuilt with inchi 1.0.4 support
  added desktop entry

* Sun Dec 04 2011 fwang <fwang> 2.3.1-1.mga2
+ Revision: 176164
- sync with fedora patches
  fix build with builddir  srcdir
- new version 2.3.1

* Sun Oct 02 2011 fwang <fwang> 2.3.0-1.mga2
+ Revision: 150856
- new version 2.3.0 (sync with mandriva)

* Wed Sep 21 2011 fwang <fwang> 2.2.3-9.mga2
+ Revision: 146362
- drop .la files
+ ahmad <ahmad>
- Rebuild against wxgtk2.8 with enabled catch_segvs

* Thu Mar 24 2011 boklm <boklm> 2.2.3-7.mga1
+ Revision: 76196
- rebuild for bug #497

* Wed Mar 16 2011 mikala <mikala> 2.2.3-6.mga1
+ Revision: 72651
- Remove wrong provides openbabel in the lib package (thks to blino)
- Remove BuildRoot

* Sun Jan 23 2011 ahmad <ahmad> 2.2.3-5.mga1
+ Revision: 35384
- drop old/unneeded scriptlets
- imported package openbabel

